Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(200)

Unified Diff: webkit/tools/test_shell/test_shell_webmimeregistry_impl.h

Issue 9969061: Changed TestShellWebMimeRegistryImpl to blacklist rather than whitelist containers and codecs. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: renamed function Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
diff --git a/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h b/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
index ecf7d4db5363c3afcb9a40835afeed450243b7f1..40ac863483cd28dd1d93f5df65b3a6f299495569 100644
--- a/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
+++ b/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
@@ -18,24 +18,25 @@ class TestShellWebMimeRegistryImpl
TestShellWebMimeRegistryImpl();
virtual ~TestShellWebMimeRegistryImpl();
- // Override to force that we only support ogg, vorbis and theora.
+ // Override to force that we only support types and codecs that are supported
+ // by all variations of Chromium.
//
// Media layout tests use canPlayType() to determine the test input files.
// Different flavours of Chromium support different codecs, which has an
// impact on how canPlayType() behaves. Since Chromium's baselines are
// generated against ogg/vorbis/theora content we need to lock down how
// canPlayType() behaves when running layout tests.
virtual WebKit::WebMimeRegistry::SupportsType supportsMediaMIMEType(
const WebKit::WebString&,
const WebKit::WebString&) OVERRIDE;
private:
- bool IsSupportedMediaMimeType(const std::string& mime_type);
- bool AreSupportedMediaCodecs(const std::vector<std::string>& codecs);
+ bool IsBlacklistedMediaMimeType(const std::string& mime_type);
+ bool HasBlacklistedMediaCodecs(const std::vector<std::string>& codecs);
- typedef base::hash_set<std::string> MimeMappings;
- MimeMappings media_map_;
- MimeMappings codecs_map_;
+ std::vector<std::string> blacklisted_media_types_;
+ std::vector<std::string> blacklisted_media_codecs_;
DISALLOW_COPY_AND_ASSIGN(TestShellWebMimeRegistryImpl);
};
« no previous file with comments | « webkit/tools/layout_tests/test_expectations.txt ('k') | webkit/tools/test_shell/test_shell_webmimeregistry_impl.cc » ('j') | no next file with comments »
@@ -18,24 +18,25 @@ class TestShellWebMimeRegistryImpl
// Media layout tests use canPlayType() to determine the test input files.
// Different flavours of Chromium support different codecs, which has an
- // impact on how canPlayType() behaves. Since Chromium's baselines are
- // generated against ogg/vorbis/theora content we need to lock down how
- // canPlayType() behaves when running layout tests.
+ // impact on how canPlayType() behaves. Since Chromium's baselines and
+ // expectations are generated against the common set of types, we need to
+ // prevent canPlayType() from indicating it supports other types when running
+ // layout tests.
virtual WebKit::WebMimeRegistry::SupportsType supportsMediaMIMEType(
const WebKit::WebString&,

Powered by Google App Engine
This is Rietveld 408576698